==> archimedes-0.0.1.tar.gz: archimedes-0.0.1/src/particlecreation.h <==
/* particlecreation.h -- This file is part of Archimedes release 0.0.1.
   Archimedes is a simulator for Submicron 2D Silicon
   Devices. It implements the Monte Carlo method
   for the simulation of the semiclassical Boltzmann equation for both
   electrons and holes. It also includes the quantum effects by means 
   of effective potential method.

   Copyright (C) 2004 Jean Michel Sellier <sellier@dmi.unict.it>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */


// ######################################################
// Created on 06 sep.2004, Siracusa, J.M.Sellier
// Last modif. : 02 Oct.2004, Siracusa, J.M.Sellier
// ######################################################

// create a new super-particle on the edge
// edge = 0 Bottom edge
// edge = 1 Right edge
// edge = 2 Upper edge
// edge = 3 Left edge

inline
void
creation(int i,real t,int edge)
{
 real c1,c2,c3,
      c4,c5,c6,c7;

// We assume that the particles are initially 
// at near thermal equilibrium
 c1=log(rnd());
 c2=SMH*sqrt(-1.5*BKTQ*c1*(1.-alphaSILICON*1.5*BKTQ*c1));
 c3=rnd();
 c4=sqrt(1.-c3*c3);
 c5=2.*PI*rnd();
 c6=sin(c5);
 c7=cos(c5);
 X=dx*(rnd()+((real) i)-1.5);
 Y=dy*(rnd()+((real) i)-1.5);
 KX=c2*c3;
 KY=c2*c4*c6;
 KZ=c2*c4*c7;
 TS=t-log(rnd())/GM;

 if((edge==0 || edge==2) && i==1) X=dx*0.5*rnd();
 if((edge==0 || edge==2) && i==nx) X=LX-dx*0.5*rnd();
 if(edge==0) Y=dy*0.5*rnd();
 if(edge==2){
   Y=LY-dy*0.5*rnd();
   KY=-KY;
 }

 if((edge==1 || edge==3) && i==1) Y=dy*0.5*rnd();
 if((edge==1 || edge==3) && i==ny) Y=LY-dy*0.5*rnd();
 if(edge==1){
   X=LX-dx*0.5*rnd();
   KX=-KX;
 }
 if(edge==3) X=dx*0.5*rnd();
}

// =================================================

==> archimedes-0.0.3.tar.gz: archimedes-0.0.3/src/particlecreation.h <==
/* particlecreation.h -- This file is part of Archimedes release 0.0.2.
   Archimedes is a simulator for Submicron 2D Silicon/GaAs
   Devices. It implements the Monte Carlo method
   for the simulation of the semiclassical Boltzmann equation for both
   electrons and holes. It also includes the quantum effects by means 
   of effective potential method.

   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */


// ######################################################
// Created on 06 sep.2004, Siracusa, J.M.Sellier
// Last modif. : 12 Jan.2005, Siracusa, J.M.Sellier
// ######################################################

// create a new super-particle on the edge
// edge = 0 Bottom edge
// edge = 1 Right edge
// edge = 2 Upper edge
// edge = 3 Left edge

inline
void
creation(int i,real t,int edge)
{
 real c1,c2,c3,
      c4,c5,c6,c7;

// We assume that the particles are initially 
// at near thermal equilibrium
 if(Material==SILICON){
  c1=log(rnd());
  c2=SMH[0]*sqrt(-1.5*BKTQ*c1*(1.-alphaSILICON*1.5*BKTQ*c1));
  c3=rnd();
  c4=sqrt(1.-c3*c3);
  c5=2.*PI*rnd();
  c6=sin(c5);
  c7=cos(c5);
  X=dx*(rnd()+((real) i)-1.5);
  Y=dy*(rnd()+((real) i)-1.5);
  KX=c2*c3;
  KY=c2*c4*c6;
  KZ=c2*c4*c7;
  IV=1;
  TS=t-log(rnd())/GM;
 }
 if(Material==GAAS){
  c1=log(rnd());
  c2=SMH[1]*sqrt(-1.5*BKTQ*c1*(1.-AF[1]*1.5*BKTQ*c1));
  c3=rnd();
  c4=sqrt(1.-c3*c3);
  c5=2.*PI*rnd();
  c6=sin(c5);
  c7=cos(c5);
  X=dx*(rnd()+((real) i)-1.5);
  Y=dy*(rnd()+((real) i)-1.5);
  KX=c2*c3;
  KY=c2*c4*c6;
  KZ=c2*c4*c7;
  IV=1;
  TS=t-log(rnd())/GM;
 }

 if((edge==0 || edge==2) && i==1) X=dx*0.5*rnd();
 if((edge==0 || edge==2) && i==nx) X=LX-dx*0.5*rnd();
 if(edge==0) Y=dy*0.5*rnd();
 if(edge==2){
   Y=LY-dy*0.5*rnd();
   KY=-KY;
 }

 if((edge==1 || edge==3) && i==1) Y=dy*0.5*rnd();
 if((edge==1 || edge==3) && i==ny) Y=LY-dy*0.5*rnd();
 if(edge==1){
   X=LX-dx*0.5*rnd();
   KX=-KX;
 }
 if(edge==3) X=dx*0.5*rnd();
}

// =================================================
